@@ -8,18 +8,10 @@ import xml.etree.ElementTree as et
 ###########################################################################
 
 
-# will search in all of the direct children of the root
-def get_root_direct_child_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None):
-    root = xml_file.getroot()
-    if root.tag == node_tag:
-        return [root]
-    return find_all_nodes(root, node_tag, node_att_name, node_att_val)
-
-
 # will return a list of nodes specified by an attribute key and an attribute value from a parent node
 def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None):
     selector = node_tag
-    return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val)
+    return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val, recursive=False)
 
 
 # will return a list of nodes which doesn't have a specific attribute
@@ -91,9 +83,12 @@ def get_node_att(node, att_name):
 
 
 # will return an xml file
-def read_xml_file(xml_path):
-    k = et.parse(xml_path)
-    return et.parse(xml_path)
+def read_xml_file(xml_path, namespace_dict=None):
+    xml = et.parse(xml_path)
+    if namespace_dict:
+        for prefix, uri in namespace_dict:
+            et.register_namespace(prefix, uri)
+    return xml
 
 
 # will save the changes made in an xml file
@@ -191,12 +186,15 @@ def get_root_node(xml_file):
     return xml_file.getroot()
 
 
-# will search for a node recursively
-def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None):
+# will search for a node
+def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None, recursive=True):
     selector = node_tag
     if node_att_name is not None:
         if node_att_val is not None:
             selector = node_tag + "/[@" + node_att_name + "='" + node_att_val + "']"
         else:
             selector = node_tag + "/[@" + node_att_name + "]"
-    return parent_node.findall(f'.//${selector}')
+    if recursive:
+        return parent_node.findall(f'.//{selector}')
+    else:
+        return parent_node.findall(selector)
